@@ -4,7 +4,7 @@ import re
 
 from typing import Dict, Optional, overload
 
-from agentbox.api.client.models import SandboxADB
+from agentbox.api.client.models import SandboxADB, InstanceAuthInfo
 from agentbox.api.client.types import Unset
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.envd.api import ENVD_API_HEALTH_ROUTE, handle_envd_api_exception
@@ -577,3 +577,25 @@ class Sandbox(SandboxSetup, SandboxApi):
             sandbox_id=self.sandbox_id,
             **config_dict,
         )
+    
+    def get_instance_auth_info(  # type: ignore
+        self,
+        request_timeout: Optional[float] = None,
+    ) -> InstanceAuthInfo:
+        """
+        Get sandbox instance auth info.
+        :param request_timeout: Timeout for the request in **seconds**
+        :return: Sandbox instance auth info
+        """
+        config_dict = self.connection_config.__dict__
+        config_dict.pop("access_token", None)
+        config_dict.pop("api_url", None)
+
+        if request_timeout:
+            config_dict["request_timeout"] = request_timeout
+
+        return SandboxApi.get_instance_auth_info(
+            sandbox_id=self.sandbox_id,
+            **config_dict,
+        )
+
