@@ -6,7 +6,7 @@ from packaging.version import Version
 from agentbox.sandbox.sandbox_api import SandboxInfo, SandboxApiBase, SandboxQuery, ListedSandbox
 from agentbox.exceptions import TemplateException
 from agentbox.api import ApiClient, SandboxCreateResponse
-from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxSSH
+from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxSSH, InstanceAuthInfo
 from agentbox.api.client.api.sandboxes import (
     get_sandboxes_sandbox_id,
     post_sandboxes_sandbox_id_timeout,
@@ -16,6 +16,7 @@ from agentbox.api.client.api.sandboxes import (
     get_sandboxes_sandbox_id_adb,
     get_sandboxes_sandbox_id_ssh,
     get_sandboxes_sandbox_id_instance_no,
+    get_sandboxes_sandbox_id_instance_auth_info,
 )
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.api import handle_api_exception
@@ -207,6 +208,54 @@ class SandboxApi(SandboxApiBase):
 
             return str(res.parsed)
         
+    @classmethod
+    def get_instance_auth_info(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+        headers: Optional[Dict[str, str]] = None,
+        proxy: Optional[ProxyTypes] = None,
+    ) -> InstanceAuthInfo:
+        """
+        Get the sandbox instance auth info(userId, instanceNo, accessKey, accessSecretKey, expireTime).
+        :param sandbox_id: Sandbox ID
+        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param request_timeout: Timeout for the request in **seconds**
+        :param headers: Additional headers to send with the request
+
+        :return: Sandbox instance auth info
+        """
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=headers,
+            proxy=proxy,
+        )
+
+        with ApiClient(
+            config,
+            limits=SandboxApiBase._limits,
+        ) as api_client:
+            res = get_sandboxes_sandbox_id_instance_auth_info.sync_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            if res.parsed is None:
+                raise Exception("Body of the request is None")
+
+            return res.parsed
+        
     @classmethod
     def _get_adb(
         cls,
